.. _API:

####################
API Reference Manual
####################

:Release: |version|
:Date: |today|

This guide provides documentation for all modules, function, methods, 
and classes within Py-ART for those in the public API.

Documentation is broken down by directory and module.

.. currentmodule:: pyart

.. autosummary::
   :toctree: generated/
    
   core
   io
   aux_io
   config
   correct
   exceptions
   retrieve
   graph
   filters
   lazydict
   map
   util
   bridge
   testing
   _debug_info
